@@ -34,10 +34,10 @@ def main():
 
     # 搜索记录
     try:
-        records = search_bitable_records(
+        result = search_bitable_records(
             app_token, table_id, view_id, field_names, "and", conditions, sort
         )
-        print(f"搜索记录成功: {lark.JSON.marshal(records, indent=4)}")
+        print(f"搜索记录成功: {lark.JSON.marshal(result, indent=4)}")
     except Exception as e:
         print(f"搜索记录失败: {e}")
 
