@@ -1,29 +1,25 @@
 from .bitable_field_type import BitableFieldType
 from .create_bitable_record import create_bitable_record
-from .field_escape import (
-    convert_in,
-    convert_out,
-    escape_in,
-    escape_out,
+from .bitable_record import (
+    BitableBaseRecord,
+    parse_bitable_record,
     bitable_field_metadata,
-    get_field_alias,
+    RecordEncoder,
+    bitable_record,
 )
 from .search_bitable_records import search_bitable_records
 from .update_bitable_record import update_bitable_record
-from .search_facade import search_bitable_records_with_page
-from .create_facade import create_bitable_record_with_type
+from .bitable_record_service import BitableRecordService
 
 __all__ = [
     "create_bitable_record",
-    "create_bitable_record_with_type",
     "search_bitable_records",
     "update_bitable_record",
     "BitableFieldType",
+    "BitableBaseRecord",
     "bitable_field_metadata",
-    "escape_in",
-    "escape_out",
-    "get_field_alias",
-    "convert_in",
-    "convert_out",
-    "search_bitable_records_with_page",
+    "parse_bitable_record",
+    "RecordEncoder",
+    "bitable_record",
+    "BitableRecordService",
 ]
