@@ -9,8 +9,10 @@ from lark_oapi.api.bitable.v1 import (
     CreateAppTableRecordRequest,
     AppTableRecord,
     CreateAppTableRecordResponse,
+    CreateAppTableRecordResponseBody,
 )
-from typing import Dict, Any
+from typing import Dict, Any, Optional
+
 from ..lark_client import client
 
 
@@ -18,7 +20,7 @@ def create_bitable_record(
     app_token: str,
     table_id: str,
     fields: Dict[str, Any],
-) -> Dict[str, Any]:
+) -> AppTableRecord:
     """
     新增多维表格记录
 
@@ -28,7 +30,7 @@ def create_bitable_record(
         fields: 字段值字典，key为字段名，value为字段值
 
     Returns:
-        Dict[str, Any]: 新增的记录数据
+        AppTableRecord: 新增的记录数据
 
     Raises:
         Exception: 新增记录失败时抛出异常
@@ -55,4 +57,4 @@ def create_bitable_record(
         raise Exception(error_msg)
 
     # 返回新增的记录数据
-    return response.data
+    return response.data.record
